@@ -1,5 +1,5 @@
 """
-@author: Thomas Delaet <thomas@delaet.org>
+:author: Thomas Delaet <thomas@delaet.org>
 """
 import velbus
 
@@ -12,6 +12,12 @@ class BusActiveMessage(velbus.Message):
     received by: VMB1USB
     """
 
+    def set_defaults(self, address):
+        if address is not None:
+            self.set_address(address)
+        self.set_high_priority()
+        self.set_no_rtr()
+
     def populate(self, priority, address, rtr, data):
         assert isinstance(data, bytes)
         self.needs_high_priority(priority)
@@ -21,7 +27,7 @@ class BusActiveMessage(velbus.Message):
 
     def data_to_binary(self):
         """
-        @return bytes
+        :return: bytes
         """
         return bytes([COMMAND_CODE])
 
