@@ -1,5 +1,5 @@
 """
-@author: Thomas Delaet <thomas@delaet.org>
+:author: Thomas Delaet <thomas@delaet.org>
 """
 import velbus
 
@@ -12,15 +12,16 @@ class BusErrorCounterStatusMessage(velbus.Message):
     received by:
     """
 
-    def __init__(self):
+    def __init__(self, address=None):
         velbus.Message.__init__(self)
         self.transmit_error_counter = 0
         self.receive_error_counter = 0
         self.bus_off_counter = 0
+        self.set_defaults(address)
 
     def populate(self, priority, address, rtr, data):
         """
-        @return None
+        :return: None
         """
         assert isinstance(data, bytes)
         self.needs_low_priority(priority)
@@ -32,9 +33,9 @@ class BusErrorCounterStatusMessage(velbus.Message):
 
     def data_to_binary(self):
         """
-        @return: bytes
+        :return: bytes
         """
         return bytes([COMMAND_CODE, self.transmit_error_counter,
-                     self.receive_error_counter, self.bus_off_counter])
+                      self.receive_error_counter, self.bus_off_counter])
 
 velbus.register_command(COMMAND_CODE, BusErrorCounterStatusMessage)
