@@ -1,5 +1,5 @@
 """
-@author: Thomas Delaet <thomas@delaet.org>
+:author: Thomas Delaet <thomas@delaet.org>
 """
 import velbus
 
@@ -12,14 +12,15 @@ class ChannelNamePart1Message(velbus.Message):
     received by:
     """
 
-    def __init__(self):
+    def __init__(self, address=None):
         velbus.Message.__init__(self)
         self.channel = 0
         self.name = ""
+        self.set_defaults(address)
 
     def populate(self, priority, address, rtr, data):
         """
-        @return None
+        :return: None
         """
         assert isinstance(data, bytes)
         self.needs_low_priority(priority)
@@ -33,12 +34,12 @@ class ChannelNamePart1Message(velbus.Message):
 
     def data_to_binary(self):
         """
-        @return: bytes
+        :return: bytes
         """
         return bytes([
-                COMMAND_CODE,
-                self.channels_to_byte([self.channel])
-                ]) + bytes(self.name, 'utf-8')
+            COMMAND_CODE,
+            self.channels_to_byte([self.channel])
+            ]) + bytes(self.name, 'utf-8')
 
 
 velbus.register_command(COMMAND_CODE, ChannelNamePart1Message)
