@@ -1,5 +1,5 @@
 """
-@author: Thomas Delaet <thomas@delaet.org>
+:author: Thomas Delaet <thomas@delaet.org>
 """
 import velbus
 
@@ -12,15 +12,16 @@ class MemoryDataBlockMessage(velbus.Message):
     received by:
     """
 
-    def __init__(self):
+    def __init__(self, address=None):
         velbus.Message.__init__(self)
         self.high_address = 0x00
         self.low_address = 0x00
         self.data = bytes([])
+        self.set_defaults(address)
 
     def populate(self, priority, address, rtr, data):
         """
-        @return None
+        :return None
         """
         assert isinstance(data, bytes)
         self.needs_low_priority(priority)
@@ -33,7 +34,7 @@ class MemoryDataBlockMessage(velbus.Message):
 
     def data_to_binary(self):
         """
-        @return: bytes
+        :return: bytes
         """
         return bytes([
             COMMAND_CODE,
