@@ -1,5 +1,5 @@
 """
-@author: Thomas Delaet <thomas@delaet.org>
+:author: Thomas Delaet <thomas@delaet.org>
 """
 import velbus
 
@@ -14,7 +14,7 @@ class MemoryDumpRequestMessage(velbus.Message):
 
     def populate(self, priority, address, rtr, data):
         """
-        @return: None
+        :return: None
         """
         self.needs_low_priority(priority)
         self.needs_no_rtr(rtr)
@@ -23,7 +23,7 @@ class MemoryDumpRequestMessage(velbus.Message):
 
     def data_to_binary(self):
         """
-        @return: bytes
+        :return: bytes
         """
         return bytes([COMMAND_CODE])
 
