@@ -1,10 +1,11 @@
 """
-@author: Thomas Delaet <thomas@delaet.org>
+:author: Thomas Delaet <thomas@delaet.org>
 """
 import velbus
 
 COMMAND_CODE = 0xed
 
+#FIXME: This is written for VMB6IN but VMB7IN transmits a different type of of module status message
 
 class ModuleStatusMessage(velbus.Message):
     """
@@ -12,16 +13,17 @@ class ModuleStatusMessage(velbus.Message):
     received by:
     """
 
-    def __init__(self):
+    def __init__(self, address=None):
         velbus.Message.__init__(self)
         self.closed = []
         self.led_on = []
         self.led_slow_blinking = []
         self.led_fast_blinking = []
+        self.set_defaults(address)
 
     def populate(self, priority, address, rtr, data):
         """
-        @return None
+        :return: None
         """
         assert isinstance(data, bytes)
         self.needs_low_priority(priority)
@@ -35,7 +37,7 @@ class ModuleStatusMessage(velbus.Message):
 
     def data_to_binary(self):
         """
-        @return: bytes
+        :return: bytes
         """
         return bytes([
             COMMAND_CODE,
