@@ -1,5 +1,5 @@
 """
-@author: Thomas Delaet <thomas@delaet.org>
+:author: Thomas Delaet <thomas@delaet.org>
 """
 import velbus
 
@@ -12,14 +12,15 @@ class ModuleStatusRequestMessage(velbus.Message):
     received by: VMB6IN, VMB4RYLD
     """
 
-    def __init__(self):
+    def __init__(self, address=None):
         velbus.Message.__init__(self)
         self.channels = []
         self.wait_after_send = 500
+        self.set_defaults(address)
 
     def populate(self, priority, address, rtr, data):
         """
-        @return None
+        :return: None
         """
         assert isinstance(data, bytes)
         self.needs_low_priority(priority)
@@ -28,14 +29,9 @@ class ModuleStatusRequestMessage(velbus.Message):
         self.set_attributes(priority, address, rtr)
         self.channels = self.byte_to_channels(data[0])
 
-    def set_defaults(self, address):
-        self.set_address(address)
-        self.set_low_priority()
-        self.set_no_rtr()
-
     def data_to_binary(self):
         """
-        @return: bytes
+        :return: bytes
         """
         return bytes([
             COMMAND_CODE,
