@@ -1,5 +1,5 @@
 """
-@author: Thomas Delaet <thomas@delaet.org>
+:author: Thomas Delaet <thomas@delaet.org>
 """
 import velbus
 
@@ -11,10 +11,15 @@ class ReceiveBufferFullMessage(velbus.Message):
     send by:
     received by: VMB1USB
     """
+    def set_defaults(self, address):
+        if address is not None:
+            self.set_address(address)
+        self.set_high_priority()
+        self.set_no_rtr()
 
     def populate(self, priority, address, rtr, data):
         """
-        @return: None
+        :return: None
         """
         self.needs_high_priority(priority)
         self.needs_no_rtr(rtr)
@@ -23,7 +28,7 @@ class ReceiveBufferFullMessage(velbus.Message):
 
     def data_to_binary(self):
         """
-        @return: bytes
+        :return: bytes
         """
         return bytes([COMMAND_CODE])
 
