@@ -1,8 +1,8 @@
 """
-@author: Thomas Delaet <thomas@delaet.org>
+:author: Thomas Delaet <thomas@delaet.org>
 """
-import velbus
 import struct
+import velbus
 
 COMMAND_CODE = 0x03
 
@@ -13,14 +13,21 @@ class StartRelayTimerMessage(velbus.Message):
     received by: VMB4RYLD
     """
 
-    def __init__(self):
+    def __init__(self, address=None):
         velbus.Message.__init__(self)
         self.relay_channels = []
         self.delay_time = 0
+        self.set_defaults(address)
+
+    def set_defaults(self, address):
+        if address is not None:
+            self.set_address(address)
+        self.set_high_priority()
+        self.set_no_rtr()
 
     def populate(self, priority, address, rtr, data):
         """
-        @return: None
+        :return: None
         """
         assert isinstance(data, bytes)
         self.needs_high_priority(priority)
@@ -32,7 +39,7 @@ class StartRelayTimerMessage(velbus.Message):
 
     def data_to_binary(self):
         """
-        @return: bytes
+        :return: bytes
         """
         return bytes([
             COMMAND_CODE,
