@@ -1,28 +1,27 @@
 """
-@author: Thomas Delaet <thomas@delaet.org>
+:author: Thomas Delaet <thomas@delaet.org>
 """
-import velbus
 import json
 import logging
+import velbus
 
 COMMAND_CODE = 0x01
 
-
 class SwitchRelayOffMessage(velbus.Message):
     """
     send by:
     received by: VMB4RYLD
     """
-    # pylint: disable-msg=R0904
 
-    def __init__(self):
+    def __init__(self, address=None):
         velbus.Message.__init__(self)
         self.relay_channels = []
         self.logger = logging.getLogger('velbus')
+        self.set_defaults(address)
 
     def populate(self, priority, address, rtr, data):
         """
-        @return: None
+        :return: None
         """
         assert isinstance(data, bytes)
         self.logger.debug("Populating message: priority %s, address: %s, channels: %s", str(
@@ -37,20 +36,21 @@ class SwitchRelayOffMessage(velbus.Message):
 
     def to_json(self):
         """
-        @return: str
+        :return: str
         """
         json_dict = self.to_json_basic()
         json_dict['channels'] = self.relay_channels
         return json.dumps(json_dict)
 
     def set_defaults(self, address):
-        self.set_address(address)
+        if address is not None:
+            self.set_address(address)
         self.set_high_priority()
         self.set_no_rtr()
 
     def data_to_binary(self):
         """
-        @return: bytes
+        :return: bytes
         """
         return bytes([
             COMMAND_CODE,
